@@ -13,7 +13,7 @@ use File::Spec::Functions qw( catdir catfile );
 use constant DEBUG    => $ENV{MOJO_ASSETPACK_DEBUG}    || 0;
 use constant NO_CACHE => $ENV{MOJO_ASSETPACK_NO_CACHE} || 0;
 
-our $VERSION = '0.67';
+our $VERSION = '0.68';
 
 our $MINIFY = undef;    # internal use only!
 my $MONIKER_RE = qr{^(.+)\.(\w+)$};
@@ -175,8 +175,9 @@ sub _build_out_dir {
     }
   }
   if (!$out_dir) {
-    die "[AssetPack] Could not auto detect out_dir: "
-      . "Neither readable, nor writeable 'packed' directory could be found in static paths, @{$app->static->paths}. Maybe you forgot to pre-pack the assets? "
+    die "[AssetPack] Neither readable, nor writeable 'out_dir' directory "
+      . "could be found in static paths @{$app->static->paths}. "
+      . "Maybe you forgot to pre-pack the assets? "
       . "https://metacpan.org/pod/Mojolicious::Plugin::AssetPack::Manual::Cookbook";
   }
 
@@ -387,7 +388,7 @@ Mojolicious::Plugin::AssetPack - Compress and convert css, less, sass, javascrip
 
 =head1 VERSION
 
-0.67
+0.68
 
 =head1 SYNOPSIS
 
